..
    Copyright (C) 2018 Esteban J. G. Gabancho.
    Invenio-S3 is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

============
 Invenio-S3
============

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-s3.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-s3

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-s3.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-s3

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-s3.svg
        :target: https://github.com/inveniosoftware/invenio-s3/releases

.. image:: https://img.shields.io/pypi/dm/invenio-s3.svg
        :target: https://pypi.python.org/pypi/invenio-s3

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-s3.svg
        :target: https://github.com/inveniosoftware/invenio-s3/blob/master/LICENSE

S3 file storage support for Invenio.

The package offers integration with any S3 REST API compatible object storage.

Further documentation is available on
https://invenio-s3.readthedocs.io/
